@@ -42,6 +42,8 @@
 #' - `m` = months
 #' - `w` = weeks
 #'
+#' All columns containing dates must be in YYYY-MM-DD format.
+#'
 #' @param .data A data frame with census-level records
 #' @param end_date Experience study end date
 #' @param start_date Experience study start date. Default value = 1900-01-01.
@@ -81,8 +83,6 @@
 #' @references Atkinson and McGarry (2016). Experience Study Calculations.
 #' <https://www.soa.org/49378a/globalassets/assets/files/research/experience-study-calculations.pdf>
 #'
-#' @importFrom lubridate %m+% %m-%
-#'
 #' @export
 expose <- function(.data,
                    end_date,
@@ -105,11 +105,13 @@ expose <- function(.data,
     paste0(prefix, "_", res, suffix)
   }
 
-
   # set up exposure period lengths
   expo_length <- rlang::arg_match(expo_length)
-  expo_step <- expo_step(expo_length)
   cal_frac <- cal_frac(expo_length)
+  cal_floor <- cal_floor(expo_length)
+  add_period <- add_period(expo_length)
+
+  n_term_dates <- sum(!is.na(.data[[col_term_date]]))
 
   # column renames and name conflicts
   .data <- .data |>
@@ -117,7 +119,18 @@ expose <- function(.data,
            status = {{col_status}},
            issue_date = {{col_issue_date}},
            term_date = {{col_term_date}}) |>
-    .expo_name_conflict(cal_expo, expo_length)
+    .expo_name_conflict(cal_expo, expo_length) |>
+    # convert to dates if needed
+    mutate(dplyr::across(c(issue_date, term_date), .convert_date))
+
+  .check_missing_dates(.data$issue_date, "issue_date")
+
+  if (n_term_dates != sum(!is.na(.data$term_date))) {
+    rlang::abort(c(
+      "Bad termination date formats were detected.",
+      i = "Make sure all dates are in YYYY-MM-DD format.")
+    )
+  }
 
   # set up statuses
   if (!is.factor(.data$status)) .data$status <- factor(.data$status)
@@ -131,13 +144,19 @@ expose <- function(.data,
     levels(.data$status) <- status_levels
   }
 
+  if (default_status %in% target_status) {
+    rlang::abort(
+      "`default_status` is not allowed to be the same as `target_status`"
+    )
+  }
+
   # pre-exposure updates
   res <- .data |>
     filter(issue_date < end_date,
            is.na(term_date) | term_date > start_date) |>
     mutate(
       term_date = dplyr::if_else(term_date > end_date,
-                                 lubridate::NA_Date_, term_date),
+                                 as.Date(NA), term_date),
       status = dplyr::if_else(is.na(term_date), default_status, status),
       last_date = pmin(term_date, end_date, na.rm = TRUE))
 
@@ -145,17 +164,14 @@ expose <- function(.data,
     res <- res |>
       mutate(
         first_date = pmax(issue_date, start_date),
-        cal_b = lubridate::floor_date(first_date, expo_length),
-        tot_per = lubridate::interval(
-          cal_b,
-          lubridate::floor_date(last_date, expo_length)
-        ) / expo_step,
-        rep_n = ceiling(tot_per) + 1)
+        cal_b = cal_floor(first_date),
+        rep_n = clock::date_count_between(cal_b, last_date,
+                                          expo_length) + 1L)
   } else {
     res <- res |>
       mutate(
-        tot_per = lubridate::interval(issue_date - 1, last_date) / expo_step,
-        rep_n = ceiling(tot_per))
+        rep_n = clock::date_count_between(issue_date, last_date,
+                                          expo_length) + 1L)
   }
 
   # apply exposures
@@ -167,13 +183,13 @@ expose <- function(.data,
     mutate(
       last_per = .time == rep_n,
       status = dplyr::if_else(last_per, status, default_status),
-      term_date = dplyr::if_else(last_per, term_date, lubridate::NA_Date_))
+      term_date = dplyr::if_else(last_per, term_date, as.Date(NA)))
 
   if (cal_expo) {
     res <- res |>
       mutate(first_per = .time == 1,
-             cal_e = cal_b %m+% (expo_step * .time) - 1,
-             cal_b = cal_b %m+% (expo_step * (.time - 1)),
+             cal_e = add_period(cal_b, .time) - 1L,
+             cal_b = add_period(cal_b, .time - 1L),
              exposure = dplyr::case_when(
                status %in% target_status ~ 1,
                first_per & last_per ~ cal_frac(last_date) -
@@ -183,7 +199,7 @@ expose <- function(.data,
                TRUE ~ 1)
       ) |>
       select(-rep_n, -first_date, -last_date, -first_per, -last_per,
-             -.time, -tot_per) |>
+             -.time) |>
       relocate(cal_e, .after = cal_b) |>
       dplyr::rename_with(.fn = rename_col, .cols = cal_b, prefix = "cal") |>
       dplyr::rename_with(.fn = rename_col, .cols = cal_e, prefix = "cal",
@@ -191,14 +207,17 @@ expose <- function(.data,
   } else {
     res <- res |>
       mutate(
-        cal_b = issue_date %m+% (expo_step * (.time - 1)),
-        cal_e = issue_date %m+% (expo_step * .time) - 1,
-        exposure = dplyr::if_else(last_per & !status %in% target_status,
-                                  tot_per %% 1, 1),
+        cal_b = add_period(issue_date, .time - 1L),
+        cal_e = add_period(issue_date, .time) - 1L,
+        exposure = dplyr::if_else(
+          last_per & !status %in% target_status,
+          as.integer((last_date - cal_b + 1))  /
+            as.integer(cal_e - cal_b + 1),
+          1),
         # exposure = 0 is possible if exactly 1 period has elapsed. replace these with 1's
         exposure = dplyr::if_else(exposure == 0, 1, exposure)
       ) |>
-      select(-last_per, -last_date, -tot_per, -rep_n) |>
+      select(-last_per, -last_date, -rep_n) |>
       filter(between(cal_b, start_date, end_date)) |>
       dplyr::rename_with(.fn = rename_col, .cols = .time, prefix = "pol") |>
       dplyr::rename_with(.fn = rename_col, .cols = cal_b, prefix = "pol_date") |>
@@ -266,31 +285,76 @@ expose_cw <- function(...) {
 
 # helper functions for calendar year fractions - do not export
 year_frac <- function(x, .offset = 0) {
-  (lubridate::yday(x) - .offset) / (365 + lubridate::leap_year(x))
+  xday <- clock::as_year_day(x) |> clock::get_day()
+  (xday - .offset) / (365 + clock::date_leap_year(x))
 }
 
 quarter_frac <- function(x, .offset = 0) {
-  (lubridate::qday(x) - .offset) /
-    lubridate::qday((lubridate::ceiling_date(x, "quarter") - 1))
+  xday <- clock::as_year_quarter_day(x) |> clock::get_day()
+  qdays <- (clock::date_group(x, "month", n = 3) |>
+              clock::add_quarters(1, invalid = "previous") - 1L) |>
+    clock::as_year_quarter_day() |>
+    clock::get_day()
+  (xday - .offset) / qdays
 }
 
 month_frac <- function(x, .offset = 0) {
-  (lubridate::mday(x) - .offset) /
-    lubridate::mday((lubridate::ceiling_date(x, "month") - 1))
+  xday <- clock::get_day(x)
+  mdays <- (clock::date_group(x, "month") |>
+              clock::add_months(1, invalid = "previous") - 1L) |>
+    clock::get_day()
+  (xday - .offset) / mdays
 }
 
 week_frac <- function(x, .offset = 0) {
-  (lubridate::wday(x) - .offset) / 7
+  (clock::as_year_week_day(x) |> clock::get_day() - .offset) / 7
 }
 
-cal_frac <- function(x) {
-  switch(x,
+cal_frac <- function(expo_length) {
+  switch(expo_length,
          "year" = year_frac,
          "quarter" = quarter_frac,
          "month" = month_frac,
          'week' = week_frac)
 }
 
+# helper functions for calendar year flooring
+year_floor <- function(x) {
+  clock::date_group(x, "year")
+}
+
+quarter_floor <- function(x) {
+  clock::date_group(x, "month", n = 3)
+}
+
+month_floor <- function(x) {
+  clock::date_group(x, "month")
+}
+
+week_floor <- function(x) {
+  sunday <- clock::weekday(clock::clock_weekdays$sunday)
+  clock::date_shift(x, target = sunday, which = "previous")
+}
+
+cal_floor <- function(expo_length) {
+  switch(expo_length,
+         "year" = year_floor,
+         "quarter" = quarter_floor,
+         "month" = month_floor,
+         'week' = week_floor)
+}
+
+# helper function for adding period
+add_period <- function(expo_length) {
+  fun <- switch(expo_length,
+                "year" = clock::add_years,
+                "quarter" = clock::add_quarters,
+                "month" = clock::add_months,
+                'week' = clock::add_weeks)
+  if (expo_length == "week") return(fun)
+  \(x, n) fun(x, n, invalid = "previous")
+}
+
 # helper function to handle name conflicts
 .expo_name_conflict <- function(.data, cal_expo, expo_length) {
 
@@ -327,11 +391,20 @@ most_common <- function(x) {
   factor(y[[1]], levels(x))
 }
 
-# helper function for determining exposure step lengths
-expo_step <- function(x) {
-  switch(x,
-         "year" = lubridate::years(1),
-         "quarter" = months(3),
-         "month" = months(1),
-         "week" = lubridate::days(7))
+is.Date <- function(x) {
+  inherits(x, "Date")
+}
+
+.convert_date <- function(x) {
+  if (is.Date(x)) return(x)
+  clock::date_parse(x, format = "%Y-%m-%d")
+}
+
+.check_missing_dates <- function(x, name) {
+  if (any(is.na(x))) {
+    rlang::abort(c(
+      glue::glue("Missing values are not allowed in the `{name}` column."),
+      i = "Make sure all dates are in YYYY-MM-DD format.")
+    )
+  }
 }
