@@ -5,8 +5,8 @@ expected_table <- c(seq(0.005, 0.03, length.out = 10), 0.2, 0.15, rep(0.05, 3))
 set.seed(123)
 study_py <- study_py |>
   mutate(expected_1 = expected_table[pol_yr],
-                expected_2 = ifelse(inc_guar, 0.015, 0.03),
-                weights = rnorm(nrow(study_py), 100, 50) |> abs())
+         expected_2 = ifelse(inc_guar, 0.015, 0.03),
+         weights = rnorm(nrow(study_py), 100, 50) |> abs())
 
 exp_res <- study_py |>
   group_by(pol_yr, inc_guar) |>
@@ -24,13 +24,6 @@ test_that("Partial credibility is between 0 and 1", {
   expect_gte(min(exp_res$credibility, exp_res$q_obs), 0)
 })
 
-test_that("Confidence intervals surround the observed surrender rate", {
-  expect_true(all(exp_res$q_obs < exp_res$q_obs_upper))
-  expect_true(all(exp_res$q_obs > exp_res$q_obs_lower))
-  expect_true(all(exp_res_weighted$q_obs < exp_res_weighted$q_obs_upper))
-  expect_true(all(exp_res_weighted$q_obs > exp_res_weighted$q_obs_lower))
-})
-
 
 test_that("Experience study summary method checks", {
   expect_identical(exp_res, summary(exp_res, pol_yr, inc_guar))
@@ -44,20 +37,6 @@ test_that("Experience study summary method checks", {
 })
 
 
-toy_expo <- toy_census |> expose("2022-12-31", target_status = "Surrender") |>
-  rename(a = exposure, b = status)
-
-renamer <- c("pol_num" = "a",
-             "status" = "b",
-             "issue_date" = "c",
-             "term_date" = "d")
-toy_census2 <- toy_census |> dplyr::rename_with(\(x) renamer[x])
-
-test_that("Renaming works", {
-  expect_error(exp_stats(toy_expo))
-  expect_no_error(exp_stats(toy_expo, col_exposure = "a", col_status = "b"))
-})
-
 test_that("Confidence intervals work", {
   expect_true(all(exp_res$q_obs_lower < exp_res$q_obs))
   expect_true(all(exp_res$q_obs_upper > exp_res$q_obs))
